<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: bigbrother-todos.xsl,v 1.3 2003/12/09 16:56:30 camille Exp $

# Copyright 2001 MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : bigbrother-todos.xsl
# Author          : Camille Bgnis
# Created On      : 2003-10-27
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes master-revisions.xml as input and adds tasks
status information into it.

-->


<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:output method="xml" encoding="UTF-8" indent="yes"/>

<!-- Default template copies elements unchanged -->

<xsl:template match="node()|@*">
  <xsl:copy>
    <xsl:apply-templates select="@*"/>
    <xsl:apply-templates/>
  </xsl:copy>
</xsl:template>


<!-- For each revision history set the status attribute to one of the
revisions to either "finished", "active" or "pending". -->

<xsl:template match="revhistory">
  <xsl:choose>
    <xsl:when test="revision/@role='2translate'">
      <!-- This is an original language module -->
      <xsl:choose>
        <xsl:when test="revision/date/text()='YYYY-MM-DD'">
          <!-- This original module is not finished yet -->
          <xsl:call-template name="revhistory-todo">
            <xsl:with-param name="status">active</xsl:with-param>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <!-- This original module is finished -->
          <xsl:call-template name="revhistory-todo">
            <xsl:with-param name="status">finished</xsl:with-param>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:when>

    <xsl:otherwise>
      <!-- This is a translated module -->
      <xsl:choose>
        <xsl:when test="../revhistory/revision[@role='2translate'][date/text()='YYYY-MM-DD']">
          <!-- The corresponding original module is not yet ready -->
          <xsl:call-template name="revhistory-todo">
            <xsl:with-param name="status">pending</xsl:with-param>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <!-- This corresponding original module is finished -->
          <xsl:call-template name="revhistory-todo">
            <xsl:with-param name="status">active</xsl:with-param>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>

</xsl:template>


<xsl:template name="revhistory-todo">
  <xsl:param name="status"/>

  <revhistory>
    <xsl:copy-of select="@*"/>
    
    <xsl:for-each select="revision">
      <!--
      <xsl:message>
        revision: <xsl:value-of select="$status"/> 
      count: <xsl:value-of select="position()"/>
      local: <xsl:value-of select="name(following-sibling::*[position()=1])"/>
    </xsl:message>
-->
    <!-- Copy the revisions adding status attribute where needed -->
      <revision>
        <xsl:copy-of select="@*"/>
        <xsl:choose>
          <xsl:when test="($status='pending' or $status='active') and date/text()='YYYY-MM-DD' and not(following-sibling::revision[date/text()='YYYY-MM-DD'])">
            <!-- Active or pending task -->
            <xsl:attribute name="status"><xsl:value-of select="$status"/></xsl:attribute>
          </xsl:when>
          <xsl:when test="$status='active' and not(../*/date/text()='YYYY-MM-DD') and position()=1">
            <!-- Finished translation -->
            <xsl:attribute name="status">finished</xsl:attribute>
          </xsl:when>
          <xsl:when test="$status='finished' and position()=1">
            <!-- Finished original -->
            <xsl:attribute name="status"><xsl:value-of select="$status"/></xsl:attribute>
          </xsl:when>
        </xsl:choose>
        
        <xsl:copy-of select="*"/>
      </revision>
      
    </xsl:for-each>
  </revhistory>
  
</xsl:template>

</xsl:stylesheet>
