<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: docs_index.xsl,v 1.7 2004/03/08 15:00:53 camille Exp $

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : docs_index.xsl
# Author          : Camille Bgnis
# Created On      : 2002-12-18 18:09
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheet builds a table linking to all $subdocs manuals made by the
"all" target 
-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0"> 

<xsl:output method="html" encoding="ISO-8859-1" indent="yes"/>

<xsl:param name="rootdir">../</xsl:param>
<xsl:param name="subdocs"/>
<xsl:param name="manualsdir"><xsl:value-of select="$rootdir"/>/manuals/</xsl:param>
<xsl:param name="conffilename">conf.xml</xsl:param>
<xsl:param name="repository.conf.file"><xsl:value-of select="$rootdir"/>/conf/repository.xml</xsl:param>

<xsl:variable name="repository.conf" select="document($repository.conf.file)"/>

<xsl:template match="/">
  
  <html> 
  <title>Available Output Documents for 
  <xsl:value-of select="configuration/repository/title"/>
  </title>
  <STYLE TYPE="text/css">
    div.done { font-size: larger; font-weight: bold; text-align: center; }
    div.eta { color: green; font-weight: bold;  }
    div.guidelines { font-size: tiny; }
    div.link { color: red; }
    div.start { font-size: smaller; align: right; font-style: italic;  }
    div.today { font-size: smaller; align: right; font-style: italic;  }
    h1 { align: center }
  </STYLE>
  <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
  <h1>Available Output Documents for 
  <xsl:value-of select="configuration/repository/title"/>
  </h1>
    <div align="center">
      <table border="2">
        <tr>
          <th>Manual \ Language</th>
          <xsl:for-each select="configuration/repository/languages/lang[not(@status='inactive')]">
            <th>
              <xsl:value-of select="text()"/>
            </th>
          </xsl:for-each>
        </tr>
        <xsl:for-each select="configuration/repository/manuals/manual[not(@status='inactive')]">
          <xsl:variable name="manual">
            <xsl:value-of select="text()"/>
          </xsl:variable>
          <xsl:variable name="conf-file"><xsl:value-of select="$manualsdir"/>/<xsl:value-of select="$manual"/>/<xsl:value-of select="$conffilename"/></xsl:variable>
          <xsl:variable name="conf" select="document($conf-file,.)"/>

          <xsl:for-each select="$conf//document[language][style]">
            <xsl:variable name="ID"><xsl:value-of select="@id"/></xsl:variable>
            <xsl:variable name="subdoc"><xsl:value-of select="$manual"/>/<xsl:value-of select="$ID"/></xsl:variable>

            <!-- has this subdoc been compiled? -->
            <xsl:if test="contains($subdocs,$subdoc)">
              <!-- Is this a multilingual manual ? -->
              <xsl:variable name="multilang">
                <xsl:value-of select="$conf//document[@id=$ID]/@multilang"/>
              </xsl:variable>
              <tr class="{$manual}">
                <th><xsl:value-of select="$ID"/></th>
                <xsl:for-each select="$repository.conf/configuration/repository/languages/lang[not(@status='inactive')]">
                  <xsl:variable name="lang">
                    <xsl:value-of select="text()"/>
                  </xsl:variable>
                  
                  <td lang="{$lang}" align="top">
                    <xsl:choose>
                      <xsl:when test="$conf//document[@id=$ID][style]/language[@lang=$lang]">
                        <!-- If this is a multilingual manual, we link to the same file -->
                        <xsl:variable name="srclang">
                          <xsl:choose>
                            <xsl:when test="not($multilang='')">
                              <xsl:value-of select="$conf//document[@id=$ID]/language[1]/@lang"/>
                            </xsl:when>
                            <xsl:otherwise><xsl:value-of select="$lang"/></xsl:otherwise>
                          </xsl:choose>
                        </xsl:variable>
                        <xsl:for-each select="$conf//document[@id=$ID]/style">
                          <a>
                            <xsl:attribute name="href"><xsl:value-of select="$srclang"/>/<xsl:value-of select="$ID"/>.<xsl:value-of select="@format"/></xsl:attribute>
                            <xsl:value-of select="@format"/>
                          </a>
                          <xsl:if test="not(position() = last())"><xsl:text> | </xsl:text></xsl:if>
                        </xsl:for-each>
                        <xsl:if test="not($multilang='')"><br/>(multilingual)</xsl:if>
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:text>N/A</xsl:text>
                      </xsl:otherwise>
                    </xsl:choose>
                
                  </td>
                </xsl:for-each>
              </tr>
            </xsl:if>
          </xsl:for-each>
        </xsl:for-each>
      </table>
    </div>
  </body>
  
</html>

</xsl:template>

</xsl:stylesheet>
