<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: extract_ids.xsl,v 1.9 2005/02/23 09:33:25 camille Exp $

# Copyright 2001-2002 MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : extract_ids.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheet takes as input an XML DocBook document, extract the
ID/revision couples from it and output that information into another
file. 

The .lang.master file, if created in the process, contains the
language code of the original of the file currently processed. -->


<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:output method="xml" encoding="ISO-8859-1" indent="yes"/>

<xsl:param name="manualpath"/>
<xsl:param name="modulepath"/>
<xsl:param name="module"/>
<xsl:param name="lang"/>

<xsl:template match="/">
  
  <!-- output couples for translated file -->
  <xsl:call-template name ="output"/>

    <!-- get pathname of master file -->
    
    
    <xsl:variable name="masterreport">
      <xsl:value-of select="$manualpath"/>/module/<xsl:value-of select="$module"/>.revisions-todo.xml</xsl:variable>
    
    <xsl:variable name="masterlang">
      <xsl:value-of select="document($masterreport,.)//module[@id=$module]/revhistory[revision[contains(revremark/text(),'write')][not(contains(date/text(),'YYYY-MM-DD'))]]/@lang"/>
    </xsl:variable>
    
    <!-- display pathname of master file -->
    <xsl:if test="not($masterlang='')">
      <xsl:document href="{$modulepath}/{$lang}/.lang.master" method="text"><xsl:value-of select="$masterlang"/></xsl:document>
    </xsl:if>


  </xsl:template>

<!-- format ID/revision couples -->

<xsl:template name ="output">

  <revisions>
    <xsl:attribute name ="file"><xsl:value-of select="$lang"/>/<xsl:value-of select="$module"/>.xml</xsl:attribute>
    <xsl:choose>
      <xsl:when test="/*[@conformance='unorder']">
        <xsl:for-each select="*/descendant::*[@id]">
          <xsl:sort select="@id"/>
          <xsl:call-template name ="element"/>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <xsl:for-each select="*/descendant::*[@id]">
            <xsl:call-template name ="element"/>
            </xsl:for-each>
          </xsl:otherwise>
        </xsl:choose>
    
  </revisions>
</xsl:template>

<!-- output element id/revision couple -->

<xsl:template name ="element">

  <element>
    <xsl:attribute name ="id">
      <xsl:value-of select="@id"/>
    </xsl:attribute>
    <xsl:attribute name ="revision">
      <xsl:variable name="revision">
        <xsl:choose>
          <xsl:when test="@revision">
            <xsl:value-of select="@revision"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="0"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:variable>
      <xsl:value-of select="$revision"/>
    </xsl:attribute>
    
    <xsl:if test="@condition">
      <xsl:attribute name="condition">
        <xsl:value-of select="@condition"/>
      </xsl:attribute>
    </xsl:if>
    
  </element>
</xsl:template>

</xsl:stylesheet>
