<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: gather_revhistories.xsl,v 1.9 2004/03/08 15:00:53 camille Exp $

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : gather_revhistories.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

this stylesheets gathers all revhistories of all modules for a single
document in a single big revhistories file. That will be used later
for various tracking purposes

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.0">

  <xsl:param name="modules-path" select="../../modules"/>

  <xsl:param name="conf-file" select="../../conf/repository.xml"/>
  <xsl:param name="authors-file" select="../../conf/authors.xml"/>
  <xsl:param name="release">1.0</xsl:param>

  <xsl:variable name="conf" select="document($conf-file,.)"/>
  <xsl:variable name="authors" select="document($authors-file,.)"/>
  <xsl:variable name="langs" select="$conf/configuration/repository/languages/lang[not(@status='inactive')]"/>


<xsl:output method="xml" encoding="UTF-8"/>
 
<xsl:template match="/">
  <modules>
    <xsl:attribute name="id">
      <xsl:value-of select="/*/@id"/>
    </xsl:attribute>
    <languages>
    </languages>
    <xsl:copy-of select="$authors"/>
    <xsl:apply-templates select="//*[@id][@role='module']"/>
    <xsl:copy-of select="$conf"/>
    <xsl:copy-of select="//document"/>

  </modules>
</xsl:template>

<xsl:template match="*[@id][@role='module']">

  <xsl:variable name="module" select="@id"/>

  <xsl:variable name="langsa" select="$conf//lang"/>

  <xsl:element name="module">
    <xsl:attribute name="id">
      <xsl:value-of select="$module"/>
    </xsl:attribute>
    <xsl:element name="title">
      <xsl:value-of select="title"/>
    </xsl:element>
    <xsl:for-each select="$langs">
      <xsl:variable name="lang">
        <xsl:value-of select="text()"/>
      </xsl:variable>
      <xsl:variable name="file"><xsl:value-of select="$modules-path"/>/<xsl:value-of select="$lang"/>/<xsl:value-of select="$module"/>.xmla</xsl:variable>
      <xsl:variable name="content" select="document($file)"/>
      <xsl:variable name="revhistory-file"><xsl:value-of select="$modules-path"/>/<xsl:value-of select="$lang"/>/.<xsl:value-of select="$module"/>.revhistory</xsl:variable>
      <xsl:variable name="revhistory" select="document($revhistory-file)"/>

      <xsl:element name="revhistory">

        <xsl:copy-of select="$revhistory/*/@*"/>
        <!-- Compute number of characters in that module for accounting purposes -->
        <xsl:attribute name="lang">
          <xsl:value-of select="$lang"/>
        </xsl:attribute>
        <xsl:attribute name="vendor">
          <xsl:value-of select="string-length($content/*)"/>
        </xsl:attribute>
        <xsl:text>
        </xsl:text>
        <!-- Copy the current revision history -->
        <xsl:variable name="revision" select="$revhistory//revision[revnumber[text()=$release]] | $revhistory//revision[@role='1time'][1]"/>
        <xsl:choose>
          <xsl:when test="$revision">
            <xsl:copy-of select="$revision"/>
          </xsl:when>
          <!-- If there is no revision the module is corrupt, copy a fake one -->
          <xsl:otherwise>
            <xsl:element name="revision">
              <xsl:element name="revnumber">
                <xsl:text>0</xsl:text>
              </xsl:element> <!-- revnumber -->
              <xsl:element name="date">
                <xsl:text>YYYY-MM-DD</xsl:text>
              </xsl:element> <!-- date -->
              <xsl:element name="authorinitials">
                <xsl:text>tbn</xsl:text>
              </xsl:element> <!-- authorinitials -->
              <xsl:element name="revremark">
                <xsl:text>corrupt</xsl:text>
              </xsl:element> <!-- revremark -->
            </xsl:element> <!-- revision -->
          </xsl:otherwise>
        </xsl:choose>
      </xsl:element> <!-- revhistory -->
    </xsl:for-each>
  </xsl:element> <!-- module -->
  <xsl:text>
  </xsl:text>

</xsl:template>


</xsl:stylesheet>
