<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: list_modules.xsl,v 1.3 2004/03/08 15:00:53 camille Exp $

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : list_modules.xsl
# Author          : Camille Bgnis
# Created On      : 2003-12-10
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes all revision histories
(reports/revhistories.xml) as input and outputs an HTML table listing
all modules and for each of them: the documents that reference them,
and the status of the module for each languages

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:param name="modules-path" select="'../modules/en'"/>
<xsl:param name="revhistories" select="'revhistories-todo.xml'"/>
<xsl:variable name="revhist" select="document($revhistories,.)"/>

<xsl:output method="xml" encoding="UTF-8" indent="yes"/>

<xsl:key name="docs" match="document/module" use="document/@id"/>

<xsl:template match="/">
  <xsl:variable name="title">
    <xsl:value-of select="$revhist//repository/title[1]"/>: all modules list
  </xsl:variable>
  <xsl:variable name="langscount">
    <xsl:value-of select="count($revhist//repository/languages/lang)+1"/>
  </xsl:variable>

  <html>
    <head>
      <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
      <title><xsl:value-of select="$title"/></title>
    </head>
    <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
      <h1><xsl:value-of select="$title"/></h1>

      <table border="1">
        <tr>
          <th>Module</th>
          <th>Title</th>
          <th>Abstract</th>
          <th>Documents</th>
          <th>Lang</th>
          <th>Status</th>
        </tr>
        <xsl:for-each select="//allmodules/module">
          <xsl:variable name="module"><xsl:value-of select="@id"/></xsl:variable>
          <xsl:variable name="file"><xsl:value-of select="$modules-path"/>/<xsl:value-of select="$module"/>.xmla</xsl:variable>
          <tr>
            <th>
              <xsl:attribute name="rowspan"><xsl:value-of select="$langscount"/></xsl:attribute>
              <xsl:value-of select="$module"/>
            </th>
            <td>
              <xsl:attribute name="rowspan"><xsl:value-of select="$langscount"/></xsl:attribute>
              <xsl:value-of select="document($file,.)//title[1]"/>
            </td>
            <td>
              <xsl:attribute name="rowspan"><xsl:value-of select="$langscount"/></xsl:attribute>
              <xsl:value-of select="substring(document($file,.)//para[1],1,200)"/>
              <xsl:text>[...]</xsl:text>
            </td>
            <td>
              <xsl:attribute name="rowspan"><xsl:value-of select="$langscount"/></xsl:attribute>
              <xsl:choose>
                <xsl:when test="count($revhist/modules/document[module[@id=$module]]) &gt; 0">
                  <xsl:for-each select="$revhist/modules/document[module[@id=$module]]">
                    <xsl:value-of select="@id"/>
                    <xsl:text> </xsl:text>
                  </xsl:for-each>      
                </xsl:when>
                <xsl:otherwise>
                  <xsl:text>NO ACTIVE DOC</xsl:text>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text>.</xsl:text>
            </td>
            <xsl:for-each select="$revhist//languages/lang">
              <xsl:variable name="lang"><xsl:value-of select="."/></xsl:variable>
              <xsl:choose>
                <xsl:when test="$revhist//modules/module[@id=$module]/revhistory[@lang=$lang]">
                  <xsl:apply-templates select="$revhist//modules/module[@id=$module]/revhistory[@lang=$lang]">
                    <xsl:with-param name="lang" select="$lang"/>
                  </xsl:apply-templates>
                </xsl:when>
                <xsl:otherwise>
                  <tr>
                    <td>
                      <xsl:text>N/A</xsl:text>   
                    </td>
                    <td>
                      <xsl:text>N/A</xsl:text>   
                    </td>
                  </tr>
                </xsl:otherwise>         
              </xsl:choose>
            </xsl:for-each>

          </tr>

        </xsl:for-each>

      </table>
    </body>
  </html>
  
</xsl:template>


<xsl:template match="revhistory">
  <xsl:param name="lang"/>
  <tr>
    <td>
      <xsl:value-of select="$lang"/>
    </td>
    <td>
      <xsl:choose>
        <xsl:when test="revision/@status='finished'">
          <xsl:text>Done</xsl:text>   
        </xsl:when>
        <xsl:when test="not(revision/@status='')">
          <xsl:value-of select="revision[@status]/revremark"/>
          <xsl:if test="revision/@status='pending'">
            <xsl:text> (Pending)</xsl:text>          
          </xsl:if>
        </xsl:when>
        <xsl:otherwise>
          <xsl:text>N/A</xsl:text>   
        </xsl:otherwise>
      </xsl:choose>
    </td>
  </tr>
</xsl:template>

</xsl:stylesheet>
