<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
# $Id: summarize_tasks.xsl,v 1.8 2004/04/14 10:36:28 camille Exp $

# Copyright 2001 MandrakeSoft S.A., tous droits rservs

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
# Project         : Mandrake Linux
# Module          : Borges
# File            : summarize_tasks.xsl
# Author          : Camille Bgnis
# Created On      : Mon May  1 16:25:21 2001
# Copyright       : Camille Bgnis camille@mandrakesoft.com,
#                    MandrakeSoft under the GPL license
#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

This stylesheets takes all revision histories (reports/revhistories.xml)
as input and outputs an HTML summary table of all tasks done by all
contributors for all declared documents for one specific major
release

-->

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  version="1.1"> 

<xsl:param name="conf-file" select="'../conf/repository.xml'"/>
<xsl:param name="release" select="'1.0'"/>
<xsl:param name="output" select="'contributions.html'"/>

<xsl:output method="text"/>

<xsl:variable name="conf" select="document($conf-file,.)"/>
<xsl:key name="tasks" match="revisions/*/type/weight" use="../name"/>

<xsl:template match="/">

  <xsl:variable name="title">
    <xsl:value-of select="document($conf-file,.)//title[1]"/>
    Release <xsl:value-of select="$release"/>
  </xsl:variable>

  <xsl:variable name="rate">
    <xsl:value-of select="document($conf-file,.)//revisions/cost"/>
  </xsl:variable>

  <xsl:document method="xml" encoding="UTF-8" indent="yes" href="{$output}">
  <html>
    <head>
      <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8"/>
      <title><xsl:value-of select="$title"/></title>
    </head>
    <body bgcolor="white" text="black" link="red" vlink="brown" alink="black">
      <h1><xsl:value-of select="$title"/></h1>
      <p>FYI: Price per written character: 
      <b class="rate"><xsl:value-of select="$rate"/></b></p>
        <font size="-1">
          <table border="1">
            <tr>
              <th>Author</th>
              <th>Module</th>
              <th>Task (weight)</th>
              <th>Language</th>
              <th>Characters<br/>(change ratio)</th>
              <th>Cost</th>
            </tr>
            
            <xsl:for-each select="//revision[string(revnumber)=$release][not(string(authorinitials)='tbn')][not(string(date)='YYYY-MM-DD')]">
              <xsl:sort select="authorinitials"/>
              <xsl:sort select="../../@id"/>
              <xsl:sort select="revremark"/>
              <xsl:variable name="task">
                <xsl:value-of select="revremark"/>
              </xsl:variable>
              <xsl:variable name="lang">
                <xsl:value-of select="../@lang"/>
              </xsl:variable>
              <xsl:variable name="weight">
                <xsl:value-of select="(//revisions[@lang=$lang]/*/type[name/text()=$task]/weight)[1]"/>
              </xsl:variable>
              <xsl:variable name="size">
                <xsl:value-of select="../@vendor"/>
              </xsl:variable>
              <xsl:variable name="ratio">
                <xsl:choose>
                  <xsl:when test="@revision and not(@role='2translate')">
                    <xsl:value-of select="@revision"/>
                  </xsl:when>
                  <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
              </xsl:variable>
              <xsl:variable name="authorinitials">
                <xsl:value-of select="authorinitials"/>
              </xsl:variable>

              <xsl:variable name="author">
                <xsl:value-of select="//authorgroup/*[@id=$authorinitials]/firstname"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="//authorgroup/*[@id=$authorinitials]/surname"/>
              </xsl:variable>

              <tr role="task">
                <td role="author"><xsl:value-of select="$author"/></td>
                <td role="module"><xsl:value-of select="../../@id"/></td>
                <td role="task"><xsl:value-of select="$task"/>
                (<xsl:value-of select="$weight"/>)</td>
                <td role="lang"><xsl:value-of select="$lang"/></td>
                <td role="size"><xsl:value-of select="$size"/>
                <xsl:if test="@revision and not(@role='2translate')">
                  (<xsl:value-of select="$ratio"/>)
                </xsl:if></td>

                <!--
                <xsl:if test="$authorinitials='al'">
                  <xsl:message>
                    <xsl:value-of select="$lang"/> <xsl:value-of select="$task"/> <xsl:value-of select="$author"/> $size <xsl:value-of select="$size"/> $ratio <xsl:value-of select="$ratio"/> $rate <xsl:value-of select="$rate"/> $weight <xsl:value-of select="$weight"/> ++ <xsl:value-of select="format-number($weight * $ratio * $size * $rate div 10,'#,##0.00')"/>
                  </xsl:message>
                </xsl:if>
-->

                <td role="cost" align="right"><xsl:value-of select="format-number($weight * $ratio * $size * $rate div 10,'#,##0.00')"/></td>
              </tr>
            </xsl:for-each>

          </table>
        </font>
    </body>
  </html>
</xsl:document>

</xsl:template>


</xsl:stylesheet>
