#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : add_default_authors_list.pl
# Author          : Camille Bgnis
# Created On      : 2003-11-10
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: add_default_authors_list.pl conf/repository.xml ll [ authortask1 authortask2 ... ]
# This script duplicates the workflow for a new "ll" language.
# It also sets default authors if provided.


use XML::LibXML;


my $conf = shift || die "$0: Where's the configuration file?!\n";
my $lang = shift || die "$0: What's the new language to be added?!\n";
my @authors;

while ( my $author= shift ) {
    push ( @authors, $author);
}

# tasks relative cost

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse conf file
my $tree = $parser->parse_file($conf);
my $root = $tree->getDocumentElement;

# get default list

my @defaultlist=$root->findnodes('//revisions[not(@lang)]');
my $defaultlist=$defaultlist[0];
my $list=$defaultlist->cloneNode(1);

$list->setAttribute('lang',$lang);

# change default authors
my @types=$list->findnodes('*/type/author/text()');
foreach my $type ( @types ) {
    my $author = shift(@authors) || "unchanged" ;
    if ($author ne "unchanged" ) {
	my $t = $tree->createTextNode($author);
	$type->replaceNode($t);
    }
}


$defaultlist->addSibling($list);


$tree->toFile($conf);
