#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : confadd.pl
# Author          : Camille Bgnis
# Created On      : Thu Jul 25 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: confadd.pl --xpath=<xpath> --value=<value> --position=<position> <filename>
# This script adds <XPath> element to <conf_file.xml>
# and puts <value> in it. Optionnaly as <position> element (first)
# If <position> is "self" then we replace the element value instead of adding a new one.


use XML::LibXML;
use Getopt::Long;    # package to handle commandline parameters


########################################################################
# initialize variables:
my $app = $0;
my $version = "$app 0.1.0    2001-11-25";
my $verbose = 0;
my ($xpath, $value, $position) = "";
########################################################################

my $usage =<<END_OF_USAGE;
Usage:  $app --help --xpath=<xpath> --value=<value> --position=<position> --verbose --version <filename>

Options:
  --help       - shows this text.
  --verbose    - self explaining.
  --version    - shows version number and exits.
  <filename>   - the XML file to add the revhistory to

@ARGV

END_OF_USAGE

sub parse_command_line {
  my ($opt_help, $opt_verbose, $opt_version);
  my $result = GetOptions(
			  'help'        => \$opt_help,
			  'xpath=s'     => \$xpath,
			  'value:s'     => \$value,
			  'position:s'  => \$position,
			  'version'     => \$opt_version,
			  'verbose!'    => \$opt_verbose,
               );

  die $usage if ( (not $result) || (not $xpath) || $opt_help );

  die "$version\n" if defined $opt_version;

  $verbose  = $opt_verbose if defined $opt_verbose;
}
parse_command_line;
my $filename= $ARGV[0] || die $usage;

if ( ! $position ) { $position="last_child" };

# die " xpath =$xpath value = $value file =$file position =$position\n";

my $parent = $xpath;
$parent =~ s,/([^/]*)$,,;
my $name=$1;

# print "$xpath\n";
# print "$file\n";

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);
$parser->complete_attributes(0);

my $new= XML::LibXML::Element->new($name);
$new->appendTextNode($value);

my $doc=$parser->parse_file($filename);

if ( $position eq "self" && $doc->findnodes($xpath) ) {
    ($doc->findnodes($xpath))[0]->replaceNode($new);
} else  {
    my @nodes = $doc->findnodes( $parent );
    for my $node (@nodes) { 
	if ( $position eq "last_child" or ! $node->hasChildNodes ) {
	    $node->appendChild($new);
	    
	} else  {
	    $node->insertBefore($new,$node->firstChild);
	}
    }
}

$doc->toFile($filename,1);

