#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : gen-templates.pl
# Author          : Camille Bgnis
# Created On      : Fri Nov 08 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: gen-templates.pl ../../modules/en/ ISO-8859-1

# This script creates template modules in parameter directory
# according to master XML file with specified encoding

# Local variables:
# mode: perl


use XML::LibXML;

my $top= "master.top.xml";
my $conf= "../../conf/repository.xml";

my $modulesdir = shift || die "$0: What's the modules directory to store modules in?!\n";
my $encoding = shift || die "$0: What's the encoding to use?!\n";

# template template strings
my $decl="<?xml version=\"1.0\" encoding=\"$encoding\"?>

";
my $psgml='

<!-- @ID@ -->
<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-parent-document: ("../../manuals/module/@lang@/psgml-top.xml" "@root@")
End:
-->
';

# guess language from dir
my $lang=$modulesdir;
$lang=~ s,.*/([^\/]+)/?,$1,;

# Rrevision history skeleton
my $revhistory='<?xml version="1.0" encoding="ISO-8859-1"?>
<revhistory conformance="1">
</revhistory>';

# parse the master.top.xml
my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(1);

# Parse module file
my $tree = $parser->parse_file($top);
my $root = $tree->getDocumentElement;

my @modules=$root->findnodes('//*[@role="module"][@id]');

foreach my $module (@modules) {
    my $modulename=$module->findvalue('@id');  

#    print "hello:".$module->toString(0,1);

#check there is no module yet
    my $templatefile=$modulesdir."/".$modulename.".xml";
    if (-s $templatefile) {
	print "****** module $modulename already exists\n";
    } else {
	print "****** Writing template for module $modulename in ~$lang~\n";
# File to store template in
	open(TEMPLATE, "> $templatefile") || die "Write error: \"$templatefile\" $!\n";
	if ($encoding eq "UTF-8" ) {
	    binmode(TEMPLATE,":utf8");
	}
	print TEMPLATE $decl;

	my $ID="";
	$ID=$module->getAttribute('id');
	if ( ! $ID ) {
	    $ID=$modulename;
	}
	$module->setAttribute("id","$ID");

# set lang attribute
	$module->setAttribute("lang","$lang");
# set role attribute to detect this is a template
	$module->setAttribute("role","template");
	print TEMPLATE $module->toString(0,1);
	my $rootgi=$module->nodeName;
	my $localpsgml=$psgml;
	$localpsgml=~ s/\@root\@/$rootgi/;
	$localpsgml=~ s/\@lang\@/$lang/;
# trick so that cvs does not expand that string in here
	my $cvsId="\$I"."d\$";
	$localpsgml=~ s/\@ID\@/$cvsId/;
	print TEMPLATE $localpsgml;
	close(TEMPLATE);
    }
# File to store Revision History
    my $revisionsfile=$modulesdir."/.".$modulename.".revhistory";
    if ( ! -s $revisionsfile) {
	open(REVHIST, "> $revisionsfile") || die "Write error: \"$revisionsfile\" $!\n";  
	print REVHIST $revhistory;
	close(REVHIST);
    }
}
