#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : get_DB_deps.pl
# Author          : Camille Bgnis
# Created On      : Fri Nov 08 2002
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: get_DB_deps master.xml /path/to/images/xx/ DocBook-conf.xml
# This script extracts from a source master file all required modules
# in language "xx" and extracts from them all required images too.
# Output the results as a list of absolute file names.

# Additionaly if an additional file is given (DocBook-conf.xml) it is
# parsed to extract additinal images needed whatever the modules
# content. (typically required by the stylesheet).


use XML::Twig;

my $top= "master.top.xml";

my $master = shift || die "$0: What's the master file?!\n";
my $manual=$master;
$manual =~ s/\..*//;
my $imagespath = shift || die "$0: What's the images files path?!\n";
my $admonitions=0;
my $conffile;
if ( $conffile = shift ) { 
    $admonitions=1;
};

# If DTD specific conf file is provided, parse it 

my %admonitions;
my %admon_handler;
my @formats;
if ($admonitions) {
    
    my $twig= new XML::Twig( KeepEncoding => 1,
			     TwigHandlers =>
			     { 'image[@tag]' => \&admon,
			       'image[@force="yes"]' => \&forceadmon,
			       'format' => \&format }
			     );
    $twig->parsefile($conffile);
    $twig->purge;
}


# parse the manual_name.xml  to extract images from it
my $twig= new XML::Twig( KeepEncoding => 1,
			 TwigHandlers =>
			 { %admon_handler,
			   'graphic' => \&image,
			   'imagedata' => \&image,
			   'inlinegraphic' => \&image }
			 );
$twig->parsefile($master);


# build %admonitions and %admon_handler from conf file
sub admon {
    my ($top, $admon)= @_;
    my $tag=$admon->att('tag');
#    print STDERR "$tag **** ".$admon->text."\n";
    $admonitions{$tag}=$admon->text;
    $admon_handler{$tag}=\&admonition;
}

# build %formats from conf file
sub format {
    my ($top, $format)= @_;
    $formats[$#formats+1]=$format->text;
}

# Print out admonitions images files needed
sub admonition {
    my ( $top, $tag)= @_;
    my $gi=$tag->gi();
#    print STDERR "$gi ---- $admonitions{$gi}\n";
    for (@formats) { print $imagespath.$admonitions{$gi}.".".$_."\n" };
}

# Print out forced admonition images
sub forceadmon {
    my ( $top, $image)= @_;
    my $file=$image->text;
    $file=~ s,.*/,,;
    for (@formats) { print $imagespath.$file.".".$_."\n" };
}

# Print out images files needed
sub image {
    my ( $top, $image)= @_;
    my $file=$image->att('fileref');
    $file=~ s,.*/,,;
    print $imagespath.$file."\n";  
}
