#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : master2edit.pl
# Author          : Camille Bgnis
# Created On      : 2004-04-06
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: master2edit.pl master.top.xml /path/to/modules
# This script takes a master specs document master.top.xml and replaces
# module elements by literal content of those modules but comments.


use XML::Twig;


my @modules;
my @refs;
my @roots;
my $content="";

my $file = shift || die "$0: What's the file to transform?!\n";
my $path = shift || die "$0: Where are the modules to import?!\n";

# get master
open(FILE, "< $file") || die "unknown file: \"$file\" $!\n";
while(<FILE>){
    s/&/&amp;/g;
    $content.=$_;
}

close (FILE);

# get the doctype as it is not handled by Twig, apparently

$content=~ s/((<\?xml .*?\?>).*<!DOCTYPE.*?)(<\w)/$2$3/s;
my $doctype=$1;
$content=~ s,<!--.*?-->,,sg;

# print "\n##############\n$doctype\n##############\n"; 

# print "\n##############\n$content\n##############\n"; 

my $top= new XML::Twig(
#		       keep_encoding => 1,
		       comments => 'drop',
		       PrettyPrint => 'indented',
		       TwigHandlers =>
		       { '*[@role="module"]' => \&module,
		         'index' => \&index }
		       );
$top->parse( $content);


for (my $i = 0; $i < $#refs+1; $i++) {

#    print $refs[$i]->text;
#    print $modules[$i]->text."\n";
#    $modules[$i]->parent->suffix($refs[$i]->text);
#    $modules[$i]->cut;

# get module's content
    my $module="";
    if ( ! $modules[$i] eq "" ) {
	open(FILE, "< $modules[$i]") || die "unknown file: \"$modules[$i]\" $!\n";
	while(<FILE>){
	    s/&/&amp;/g;
	    $module.=$_;
	}
	close (FILE);
	$module=~ s,<!--.*?-->,,sg;
    }
    my $root=$roots[$i];
    my $head="\n<!-- Module $refs[$i] Begins -->\n";
    my $foot="\n<!-- Module $refs[$i] Ends -->\n";
#    print STDERR ",<$root .*?$refs[$i].*?$root>,$module,\n";
    $content=~ s,<$root [^>]*$refs[$i].*?$root>,$head$module$foot,s;
}

$content=~ s,&amp;,&,g;
$content=~ s,<\?xml [^>]*?>\n?,,g;
$content=~ s,</?>\n,,g;
$content=~ s,</?>,,g;

$content=$doctype."\n".$content;
print $content;

sub module
{ my( $top, $module)= @_;
  my $ID = $module->att("id");
#  print STDERR "*************************** $ID\t";
  $refs[$#refs+1] = $ID;
  $roots[$#roots+1] = $module->gi();
  $modules[$#modules+1] = "$path/$ID.xml";
#  print STDERR "$modules[$#modules]\n";
#  print STDERR "$refs[$#refs]\n";
}

sub index
{ my( $top, $module)= @_;
  my $ID = $module->att("id");
  $roots[$#roots+1] = $module->gi();
  $refs[$#refs+1] = $ID;
  $modules[$#modules+1] ="";
}
