#!/usr/bin/perl -w

# masterize-module
#
# (C) 2002 by Fabian Mandelbaum <fabman at mandrakesoft dot com> for the
# Borges Project (http://sourceforge.net/projects/borges-dms)
# (C) 2003 by Camille Bgnis <camille at mandrakesoft dot com> for the
#
# Takes a module and prepares it for single-module compilation
# making a master.top.xml out of the module using the module's root element
# as master.top.xml's root element.
#
# It is ASSUMED that a file named 'entities' exists defining all entities


use XML::LibXML;

# This hash associate to each possible module root element the parent
# element that will be used to construct the fake master

# Each module is embedded in at least one parent. If more than one
# ancestor is needed, each one is separated by a semi-colon ";"
# If the DTD requires additional content before or after a child, 
# this content can be added separated by commas. See example.

my %parents = (
	       "para"=> "article",
	       "abstract"=> "article",
	       "preface"=> "article",
	       "articleinfo"=> "article",
	       "legalnotice"=> "book,<title></title>,<chapter><title></title><para></para></chapter>;bookinfo",
	       "partintro"=> "part,,<chapter><title></title><para></para></chapter>",
	       "section"=> "article",
	       "simplesect"=> "article",
	       "sect5"=> "sect4",
	       "sect4"=> "sect3",
	       "sect3"=> "sect2",
	       "sect2"=> "sect1",
	       "sect1"=> "article",
	       "appendix"=> "article",
	       "chapter"=> "book",
	       "article"=> "book",
	       "glossary" => "chapter",
#	       "glossary" => "book,<title>Glossary</title>,<chapter><title></title><para></para></chapter>;bookinfo",
	       "book"=> "set",
	       );

my $module = $ARGV[0] || die "****** I need a module name!";
my $out = 'master.top.xml'; # = $inputFile;
#$out =~ s/\.xml$/-masterized\.xml/;
my $outputFile = $ARGV[1] || $out;
my $dtdPath = $ARGV[2] || '/usr/share/sgml/docbook/xml-dtd-4.2/docbookx.dtd';
my $modulename= $module;
$modulename=~ s,.*/(.*)\.xml,$1,;

# parse module
my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

# Parse module file
my $tree = $parser->parse_file($module."a");
my $root = $tree->getDocumentElement;

# and extract
my $documentType = $root->nodeName; # the root element's name
my $moduleID = $root->getAttribute("id"); # the module's ID

# in which elements should the module be included?
my @ancestors = split(";",$parents{$documentType});


# master root element
my @rootgi=split(",",$ancestors[0]);
my $rootgi=$rootgi[0];

open(OUTPUT,">$outputFile") || die "ERROR: Cannot open output file: '$outputFile'.\n";

#output XML header
print OUTPUT "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n";

#output DOCTYPE
print OUTPUT "<!DOCTYPE ", $rootgi, " SYSTEM \"$dtdPath\" [\n<!ENTITY % entities SYSTEM \"entities\">\n%entities;\n]>\n";


#output content
filldoc(@ancestors);

sub filldoc {
    my $parentfill=shift;
# $fill is used to add optional fake content to build a valid module
    my ($parent,$before,$after)=split(",",$parentfill);
    print OUTPUT "<$parent lang=\"&lang;\">\n";
    print OUTPUT "$before\n" unless ( ! $before) ;
    if ( @_ ) { filldoc (@_) } else {
	print OUTPUT "<title>Module: $modulename</title>\n";
	print OUTPUT "<$documentType role=\"module\" id=\"$modulename\">\n";
	print OUTPUT "<para>$moduleID</para>\n";
	print OUTPUT "</$documentType>\n";
    }
    print OUTPUT "$after\n" unless ( ! $after) ;
    print OUTPUT "</$parent>\n";

}

close OUTPUT;
