#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : tie_ml_doc.pl
# Author          : Camille Bgnis
# Created On      : 2003-11-20
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: tie_ml_doc.pl my_doc master.xml

# This script first extracts the languages defined for my_doc document
# in conf.xml. It then takes the my_doc.xx.flat.xml file (xx being the
# first language defined) as a base and looks for the lang="multi"
# element in it. It then addds after that element all the lang="multi"
# elements found in the others my_doc.yy.flat.xml files, in conf.xml
# langugaes order. Result is written in master.xml.

#  Additionnaly, file paths (images notably) are changed from images/
# to images/xx/, and IDs and IDRefs are adapted by suffixing them with
# language code, to ensure result is XML valid (no duplicated IDs).



use XML::LibXML;

my $doc = shift || die "$0: What's the document to process?!\n";
my $target = shift || die "$0: Where to store the multimingual master document?!\n";

my $conf="conf.xml";

my $parser=XML::LibXML->new();
$parser->expand_entities(1);
$parser->load_ext_dtd(0);

# Parse conf file
my $tree = $parser->parse_file($conf);
my $root = $tree->getDocumentElement;

# Get multilingual element path.
my $multipath=$root->findnodes("//document[\@id=\"$doc\"]/\@multilang");
# build languages list.
my @langs=$root->findnodes("//document[\@id=\"$doc\"]/language/\@lang");

# load base master
my $masterlangatt=$langs[0];
my $masterlang=$masterlangatt->nodeValue;
my $mastermaster=$doc.".".$masterlang.".flat.xml";
$tree = $parser->parse_file($mastermaster);
my $master = $tree->getDocumentElement;

# After which element will I add localized parts ?
my $multilangElt=($master->findnodes($multipath))[0];
my $insertafter=$multilangElt->previousSibling();
$multilangElt->unbindNode();

# process all languages
foreach my $langnode (@langs) {
    my $lang=$langnode->nodeValue;
    my $localmaster=$doc.".".$lang.".flat.xml";
    $tree = $parser->parse_file($localmaster);
    $root = $tree->getDocumentElement;
    my $elt=($tree->findnodes($multipath))[0];
    my @idrefs=$elt->findnodes('//*[@id|@linkend|@endterm|@linkmode]');
# Fix IDs and IDREFs
    foreach my $IDS (@idrefs) {
	foreach my $att (("id","linkend","endterm","linkmode")) {
	    if ( $IDS->hasAttribute($att)) {
		 my $id=$IDS->getAttribute($att);
		 $id.="-$lang";
		 $IDS->setAttribute($att,$id);
	     }
	}
    }
# use localized images
    my @images=$elt->findnodes('//*[@fileref]');
    foreach my $image (@images) {
	my $att="fileref";
	my $filename=$image->getAttribute($att);
	$filename=~s,(images/),../$1$lang/,;
	$image->setAttribute($att,$filename);
    }
# set lang attribute
    $elt->setAttribute("lang",$lang);
# add the localized element
    $master->insertAfter($elt,$insertafter);
    $insertafter=$elt;
}

# fix entities
my $masterstring= $master->toString(1,1);

# I need now to get header back
my $header="";
open(FILE, "< $mastermaster") || die "unknown file: \"$mastermaster\" $!\n";  
while(<FILE>){ $header.=$_; };
close (FILE);
$header=~s/(.*?<!DOCTYPE [^\]]*\]\s*>).*/$1/sg;

$masterstring=$header."\n\n".$masterstring;

# Save Result
open(MASTER, "> $target") || die "$0: Write error: \"$target\" $!\n";  
print MASTER $masterstring;
close(MASTER);
