#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : migrate-0.009-0.010.pl
# Author          : Camille Bgnis
# Created On      : 2003-05-28
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: migrate-0.009-0.010.pl

# This script migrates a master.top.xml to conform to 0.10.0 version
# file formats.

use strict;
use XML::LibXML;

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

print "Modifying master.top.xml.....\n";

my $masterfile="master.top.xml";
my $tree = $parser->parse_file($masterfile);
my $root = $tree->getDocumentElement;

my @modules=$root->findnodes('//*[para[@role="module"]]');

foreach my $module (@modules) {
    my @para=$module->findnodes('//para[@role="module"]');
    my $para=$para[0];
    my $id=$para->textContent;
    $para->removeAttribute("role");
    $module->setAttribute("role","module");
    $module->setAttribute("id",$id);
    print "Transforming $id\n";
}
my $content=$root->toString(1,1);

# reget doctype
my $doctype="";
open(FILE, "< $masterfile") || die "unknown file: \"$masterfile\" $!\n";  
while(<FILE>){ $doctype.=$_; };
close (FILE);

$doctype=~s/(.*<!DOCTYPE [^\]]*\]\s*>).*/$1/s;
$content=$doctype."\n".$content;

# Save Result
open(FILE, "> $masterfile") || die "$0: Write error: \"$masterfile\" $!\n";    
print FILE $content;
close(FILE);

# Now to the Configuration file

print "Modifying conf.xml.....\n";

my $conffile="conf.xml";

$content="";
open(FILE, "< $conffile") || die "unknown file: \"$conffile\" $!\n";  
while(<FILE>){
    s,<dssslprint>(.*)</dssslprint>,<style format="pdf" toolchain="jade">$1</style>,;
    s,<xslxhtmlflat>(.*)</xslxhtmlflat>,<style format="flat.html" toolchain="xsl">$1</style>,;
    s,<xslxhtmlchunk>(.*)</xslxhtmlchunk>,<style format="html" toolchain="xsl">$1</style>,;
    s,</?manuals>,,;
    s,</?stylesheet>,,;
    s,<manual,<document,;
    s,</manual>,</document>,;
    s,<format>(.*)</format>,<style format="$1"/>,;
    s,<lang>(.*)</lang>,<language lang="$1"/>,;
    $content.=$_;
};
close (FILE);

# Save Result
open(FILE, "> $conffile") || die "$0: Write error: \"$conffile\" $!\n";    
print FILE $content;
close(FILE);
