#! /usr/bin/perl -w
#---------------------------------------------------------------
# Project         : Linux-Mandrake
# Module          : bin
# File            : migrate-0.8.3-0.9.0.pl
# Author          : Camille Bgnis
# Created On      : 2003-05-28
# Copyright       : Camille Bgnis <camille@mandrakesoft.com>,
#                    MandrakeSoft under the GPL license
#---------------------------------------------------------------
# synopsis: migrate-0.8.3-0.9.0.pl

# This script migrates a Borges repository to conform to 0.9.0 version
# file formats. It notably store modules revision histories in another
# hidden file, and stores the new workflow scheme in repository.xml

use strict;
use XML::LibXML;

my $parser=XML::LibXML->new();
$parser->expand_entities(0);
$parser->load_ext_dtd(0);

print "Cleaning repository.....\n";
`make cleaner`;

print "Updating workflow in conf/repository.xml.....\n";

# get new workflow
my $conffile="/usr/share/Borges/template/conf/repository.xml";
open(CONF, "< $conffile") || die "Write error: \"$conffile\" $!\n";
my $workflow="";
while(<CONF>){
    $workflow.=$_;
}
close(CONF);
$workflow=~ s,.*(<revisions>.*<\/revisions>).*,$1,s;

# replace it in conf file
$conffile="conf/repository.xml";
open(CONF, "< $conffile") || die "Write error: \"$conffile\" $!\n";
my $content="";
while(<CONF>){
    $content.=$_;
}
close(CONF);
$content=~ s,<revisions>.*<\/revisions>,$workflow,s;

open(CONF, "> $conffile") || die "Write error: \"$conffile\" $!\n";
print CONF $content;
close(CONF);


print "Getting modules list.....\n";
my @modules=split(/\s+/,`ls modules/*/*.xml`);

foreach my $module (@modules) {
    print "Converting $module\n";
    my $modulea=$module."a";
    $modulea=~s,(.*/),,;
    my $path=$1;

    `make -C $path $modulea`;
    
# parse the module to extract info from it
    my $tree = $parser->parse_file($path.$modulea);
    my $root = $tree->getDocumentElement;

    my $rootgi=$root->nodeName;

    my $info=$rootgi."info";

#    print "Root: $rootgi: ".'//'.$info.'/revhistory'."\n";

    
    my @revhist=$root->findnodes('//'.$info.'/revhistory');

    if ( $revhist[0] ) {
# add new attributes
	$revhist[0]->setAttribute( "revisionflag" , '0');
	$revhist[0]->setAttribute( "conformance" , '1' );
	
# store revision history
	my $revhistfile=$module;
	$revhistfile=~s,(.*/)(.*)\.xml,$1.$2.revhistory,;
	open(REV, "> $revhistfile") || die "Write error: \"$module\" $!\n";
	print REV $revhist[0]->toString(1);
	close(REV);
	
	
# remove revhistory from module
	open(MOD, "< $module") || die "Write error: \"$module\" $!\n";
	$content="";
# And change IDs format
	while(<MOD>){
	    s/id=\"([\w-]+-\w\w\d+\")/id=\"BId-$1/g;
	    $content.=$_;
	}
	close(MOD);
	$content=~ s,<$info>.*</$info>,,s;
	
	open(MOD, "> $module") || die "Write error: \"$module\" $!\n";
	print MOD $content;
	close(MOD);

    }

}

